Command function to optimize 1 non-adverse impact objective and 1 adverse impact objective via NBI algorithm
ParetoR_1C_1AIR(Rx, Rxy1, sr, prop1, d1, Spac = 10, graph = FALSE)out Pareto-Optimal solution with objective outcome values (Criterion) and predictor Weights_1C_1AIR (ParetoWeights)
Matrix with intercorrelations among predictors
Vector with correlation between each predictor and criterion 1
Selection ratio in the full applicant pool
Proportion of minority applicants in full applicant pool
Subgroup difference; standardized mean differences between minority and majority subgroups on each predictor in full applicant pool
Number of solutions
If TRUE, plots will be generated for Pareto-optimal curve and predictor Weights_1C_1AIR