Command function to optimize 1 non-adverse impact objective and 2 adverse impact objectives via NBI algorithm
ParetoR_1C_2AIR(sr, prop1, prop2, Rx, Rxy1, d1, d2, Spac = 10)out Pareto-Optimal solution with objective outcome values (Criterion) and predictor weights (ParetoWeights)
Selection ratio in the full applicant pool
Proportion of minority1 applicants in the full applicant pool
Proportion of minority2 applicants in the full applicant pool
Matrix with intercorrelations among predictors
Vector with correlation between each predictor and the non-adverse impact objective
Subgroup difference 1; standardized mean differences between minority1 and majority subgroups on each predictor in full applicant pool
Subgroup difference 2; standardized mean differences between minority2 and majority subgroups on each predictor in full applicant pool
Number of solutions